""" CISCO_ENTITY_ALARM_MIB 

This MIB module defines the managed objects that support the
monitoring of alarms generated by physical entities contained
by the system, including chassis, slots, modules, ports, power
supplies, and fans.  In order to monitor alarms generated by a
physical entity, it must be represented by a row in the
entPhysicalTable (see ENTITY\-MIB).

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class AlarmSeverity(Enum):
    """
    AlarmSeverity

    Each alarm type defined by a vendor type employed by the

    system has an associated severity.  Bellcore TR\-NWT\-000474

    defines these severities as follows\:

    'critical'  An alarm used to indicate a severe, service\-

                affecting condition has occurred and that immediate

                corrective action is imperative, regardless of the

                time of day or day of the week.

    'major'     An alarm used for hardware or software conditions

                that indicate a serious disruption of service or the

                malfunctioning or failure of important hardware.

                These troubles require the immediate attention and

                response of a technician to restore or maintain

                system capability.  The urgency is less than in

                critical situations because of a lesser immediate

                or impending effect on service or system

                performance.

    'minor'     An alarm used for troubles that do not have a

                serious effect on service to customers or for

                troubles in hardware that are not essential to

                the operation of the system.

    'info'      An indication used to raise attention to a condition

                that could possibly be an impending problem or to 

                notify the customer of an event that improves

                operation.

    .. data:: critical = 1

    .. data:: major = 2

    .. data:: minor = 3

    .. data:: info = 4

    """

    critical = Enum.YLeaf(1, "critical")

    major = Enum.YLeaf(2, "major")

    minor = Enum.YLeaf(3, "minor")

    info = Enum.YLeaf(4, "info")



class CISCOENTITYALARMMIB(Entity):
    """
    
    
    .. attribute:: cealarmmonitoring
    
    	
    	**type**\:  :py:class:`Cealarmmonitoring <ydk.models.cisco_ios_xe.CISCO_ENTITY_ALARM_MIB.CISCOENTITYALARMMIB.Cealarmmonitoring>`
    
    .. attribute:: cealarmhistory
    
    	
    	**type**\:  :py:class:`Cealarmhistory <ydk.models.cisco_ios_xe.CISCO_ENTITY_ALARM_MIB.CISCOENTITYALARMMIB.Cealarmhistory>`
    
    .. attribute:: cealarmfiltering
    
    	
    	**type**\:  :py:class:`Cealarmfiltering <ydk.models.cisco_ios_xe.CISCO_ENTITY_ALARM_MIB.CISCOENTITYALARMMIB.Cealarmfiltering>`
    
    .. attribute:: cealarmdescrmaptable
    
    	For each type of entity (represented entPhysicalVendorType OID), this table contains a mapping between a unique  ceAlarmDescrIndex and entPhysicalvendorType OID
    	**type**\:  :py:class:`Cealarmdescrmaptable <ydk.models.cisco_ios_xe.CISCO_ENTITY_ALARM_MIB.CISCOENTITYALARMMIB.Cealarmdescrmaptable>`
    
    .. attribute:: cealarmdescrtable
    
    	This table contains a description for each alarm type defined by each vendor type employed by the system. Observe that this table is sparse in nature, as it is rarely the case that a physical entity type needs to  define every alarm in its alarm space
    	**type**\:  :py:class:`Cealarmdescrtable <ydk.models.cisco_ios_xe.CISCO_ENTITY_ALARM_MIB.CISCOENTITYALARMMIB.Cealarmdescrtable>`
    
    .. attribute:: cealarmtable
    
    	This table specifies alarm control and status information related to each physical entity contained by the system, including the alarms currently being asserted by each physical entity capable of generating alarms
    	**type**\:  :py:class:`Cealarmtable <ydk.models.cisco_ios_xe.CISCO_ENTITY_ALARM_MIB.CISCOENTITYALARMMIB.Cealarmtable>`
    
    .. attribute:: cealarmhisttable
    
    	This table contains a history of ceAlarmIndicate and ceAlarmClear traps generated by the agent
    	**type**\:  :py:class:`Cealarmhisttable <ydk.models.cisco_ios_xe.CISCO_ENTITY_ALARM_MIB.CISCOENTITYALARMMIB.Cealarmhisttable>`
    
    .. attribute:: cealarmfilterprofiletable
    
    	This table contains a list of alarm filter profiles
    	**type**\:  :py:class:`Cealarmfilterprofiletable <ydk.models.cisco_ios_xe.CISCO_ENTITY_ALARM_MIB.CISCOENTITYALARMMIB.Cealarmfilterprofiletable>`
    
    

    """

    _prefix = 'CISCO-ENTITY-ALARM-MIB'
    _revision = '1999-07-06'

    def __init__(self):
        super(CISCOENTITYALARMMIB, self).__init__()
        self._top_entity = None

        self.yang_name = "CISCO-ENTITY-ALARM-MIB"
        self.yang_parent_name = "CISCO-ENTITY-ALARM-MIB"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {"ceAlarmMonitoring" : ("cealarmmonitoring", CISCOENTITYALARMMIB.Cealarmmonitoring), "ceAlarmHistory" : ("cealarmhistory", CISCOENTITYALARMMIB.Cealarmhistory), "ceAlarmFiltering" : ("cealarmfiltering", CISCOENTITYALARMMIB.Cealarmfiltering), "ceAlarmDescrMapTable" : ("cealarmdescrmaptable", CISCOENTITYALARMMIB.Cealarmdescrmaptable), "ceAlarmDescrTable" : ("cealarmdescrtable", CISCOENTITYALARMMIB.Cealarmdescrtable), "ceAlarmTable" : ("cealarmtable", CISCOENTITYALARMMIB.Cealarmtable), "ceAlarmHistTable" : ("cealarmhisttable", CISCOENTITYALARMMIB.Cealarmhisttable), "ceAlarmFilterProfileTable" : ("cealarmfilterprofiletable", CISCOENTITYALARMMIB.Cealarmfilterprofiletable)}
        self._child_list_classes = {}

        self.cealarmmonitoring = CISCOENTITYALARMMIB.Cealarmmonitoring()
        self.cealarmmonitoring.parent = self
        self._children_name_map["cealarmmonitoring"] = "ceAlarmMonitoring"
        self._children_yang_names.add("ceAlarmMonitoring")

        self.cealarmhistory = CISCOENTITYALARMMIB.Cealarmhistory()
        self.cealarmhistory.parent = self
        self._children_name_map["cealarmhistory"] = "ceAlarmHistory"
        self._children_yang_names.add("ceAlarmHistory")

        self.cealarmfiltering = CISCOENTITYALARMMIB.Cealarmfiltering()
        self.cealarmfiltering.parent = self
        self._children_name_map["cealarmfiltering"] = "ceAlarmFiltering"
        self._children_yang_names.add("ceAlarmFiltering")

        self.cealarmdescrmaptable = CISCOENTITYALARMMIB.Cealarmdescrmaptable()
        self.cealarmdescrmaptable.parent = self
        self._children_name_map["cealarmdescrmaptable"] = "ceAlarmDescrMapTable"
        self._children_yang_names.add("ceAlarmDescrMapTable")

        self.cealarmdescrtable = CISCOENTITYALARMMIB.Cealarmdescrtable()
        self.cealarmdescrtable.parent = self
        self._children_name_map["cealarmdescrtable"] = "ceAlarmDescrTable"
        self._children_yang_names.add("ceAlarmDescrTable")

        self.cealarmtable = CISCOENTITYALARMMIB.Cealarmtable()
        self.cealarmtable.parent = self
        self._children_name_map["cealarmtable"] = "ceAlarmTable"
        self._children_yang_names.add("ceAlarmTable")

        self.cealarmhisttable = CISCOENTITYALARMMIB.Cealarmhisttable()
        self.cealarmhisttable.parent = self
        self._children_name_map["cealarmhisttable"] = "ceAlarmHistTable"
        self._children_yang_names.add("ceAlarmHistTable")

        self.cealarmfilterprofiletable = CISCOENTITYALARMMIB.Cealarmfilterprofiletable()
        self.cealarmfilterprofiletable.parent = self
        self._children_name_map["cealarmfilterprofiletable"] = "ceAlarmFilterProfileTable"
        self._children_yang_names.add("ceAlarmFilterProfileTable")
        self._segment_path = lambda: "CISCO-ENTITY-ALARM-MIB:CISCO-ENTITY-ALARM-MIB"


    class Cealarmmonitoring(Entity):
        """
        
        
        .. attribute:: cealarmcriticalcount
        
        	The value of this object specifies the number of alarms currently asserted with a severity of 'critical'
        	**type**\: int
        
        	**range:** 0..4294967295
        
        .. attribute:: cealarmmajorcount
        
        	The value of this object specifies the number of alarms currently asserted with a severity of 'major'
        	**type**\: int
        
        	**range:** 0..4294967295
        
        .. attribute:: cealarmminorcount
        
        	The value of this object specifies the number of alarms currently asserted with a severity of 'minor'
        	**type**\: int
        
        	**range:** 0..4294967295
        
        .. attribute:: cealarmcutoff
        
        	If the management client writes a value of 'true' to this object, the agent stops signalling all external audible alarms under the control of the agent.  Reading this object should always result in a value of 'false'.  Observe that alarm cutoff does not have an effect on monitoring, history logging, generation of notifications, or syslog message generation.  It also does not prevent the agent from signalling external audible alarms for alarms asserted after alarm\-cutoff.  This object emulates the 'alarm cut\-off' mechanism typically installed in a central office (e.g., a big red button).  Observe this object should neither affect external visual alarms under the control of the agent, nor should it affect the current state of alarms being asserted by the system
        	**type**\: bool
        
        

        """

        _prefix = 'CISCO-ENTITY-ALARM-MIB'
        _revision = '1999-07-06'

        def __init__(self):
            super(CISCOENTITYALARMMIB.Cealarmmonitoring, self).__init__()

            self.yang_name = "ceAlarmMonitoring"
            self.yang_parent_name = "CISCO-ENTITY-ALARM-MIB"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {}

            self.cealarmcriticalcount = YLeaf(YType.uint32, "ceAlarmCriticalCount")

            self.cealarmmajorcount = YLeaf(YType.uint32, "ceAlarmMajorCount")

            self.cealarmminorcount = YLeaf(YType.uint32, "ceAlarmMinorCount")

            self.cealarmcutoff = YLeaf(YType.boolean, "ceAlarmCutOff")
            self._segment_path = lambda: "ceAlarmMonitoring"
            self._absolute_path = lambda: "CISCO-ENTITY-ALARM-MIB:CISCO-ENTITY-ALARM-MIB/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(CISCOENTITYALARMMIB.Cealarmmonitoring, ['cealarmcriticalcount', 'cealarmmajorcount', 'cealarmminorcount', 'cealarmcutoff'], name, value)


    class Cealarmhistory(Entity):
        """
        
        
        .. attribute:: cealarmhisttablesize
        
        	This object specifies the number of entries that the  ceAlarmHistTable can contain.  When a physical entity generates an unfiltered alarm, and the capacity of the ceAlarmHistTable has reached the value specified by this object, then the agent deletes the oldest entity in order to accommodate the new entry. A value of '0' prevents any history from being retained.  
        	**type**\: int
        
        	**range:** 0..500
        
        .. attribute:: cealarmhistlastindex
        
        	This object specifies the value of the ceAlarmHistIndex object corresponding to the last entry added to the table by the agent.  If the management client uses the notifications defined by this module, then it can poll this object to determine whether it has missed a notification sent by the agent
        	**type**\: int
        
        	**range:** 0..4294967295
        
        

        """

        _prefix = 'CISCO-ENTITY-ALARM-MIB'
        _revision = '1999-07-06'

        def __init__(self):
            super(CISCOENTITYALARMMIB.Cealarmhistory, self).__init__()

            self.yang_name = "ceAlarmHistory"
            self.yang_parent_name = "CISCO-ENTITY-ALARM-MIB"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {}

            self.cealarmhisttablesize = YLeaf(YType.int32, "ceAlarmHistTableSize")

            self.cealarmhistlastindex = YLeaf(YType.uint32, "ceAlarmHistLastIndex")
            self._segment_path = lambda: "ceAlarmHistory"
            self._absolute_path = lambda: "CISCO-ENTITY-ALARM-MIB:CISCO-ENTITY-ALARM-MIB/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(CISCOENTITYALARMMIB.Cealarmhistory, ['cealarmhisttablesize', 'cealarmhistlastindex'], name, value)


    class Cealarmfiltering(Entity):
        """
        
        
        .. attribute:: cealarmnotifiesenable
        
        	This object specifies a severity threshold governing the generation of ceAlarmAsserted and ceAlarmCleared notifications.  For example, if the value of this object is set to 'major', then the agent generates these notifications if and only if the severity of the alarm being indicated is 'major' or 'critical'.  The value of '0' disables the  generation of notifications.  Observe that this setting overrides the value of the  ceAlarmFilterNotifiesEnabled object.  This object affects notification generation only; that is, it does not affect monitoring, history logging, and syslog message generation
        	**type**\: int
        
        	**range:** 0..4
        
        .. attribute:: cealarmsyslogenable
        
        	This object specifies a severity threshold governing the generation of syslog messages corresponding to alarms.  For example, if the value of this object is set to 'major', then the agent generates these a syslog message if and only if the severity of the alarm being indicated is 'major' or 'critical'. The value of '0' disables the generation of syslog messages corresponding to alarms.  Observe that this setting overrides the value of the  ceAlarmFilterSyslogEnabled object.  This object affects syslog message generation only; that is, it does not have an effect on monitoring, history logging, and generation of notifications
        	**type**\: int
        
        	**range:** 0..4
        
        .. attribute:: cealarmfilterprofileindexnext
        
        	This object contains an appropriate value to be used for ceAlarmFilterIndex when creating entries in the ceAlarmFilterProfileTable.  The value '0' indicates that no unassigned entries are available.  To obtain a ceAlarmFilterIndex, the management client issues a get request.  The agent has the responsibility of  modifying the value of this object following each  successful get request
        	**type**\: int
        
        	**range:** 0..4294967295
        
        

        """

        _prefix = 'CISCO-ENTITY-ALARM-MIB'
        _revision = '1999-07-06'

        def __init__(self):
            super(CISCOENTITYALARMMIB.Cealarmfiltering, self).__init__()

            self.yang_name = "ceAlarmFiltering"
            self.yang_parent_name = "CISCO-ENTITY-ALARM-MIB"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {}

            self.cealarmnotifiesenable = YLeaf(YType.int32, "ceAlarmNotifiesEnable")

            self.cealarmsyslogenable = YLeaf(YType.int32, "ceAlarmSyslogEnable")

            self.cealarmfilterprofileindexnext = YLeaf(YType.uint32, "ceAlarmFilterProfileIndexNext")
            self._segment_path = lambda: "ceAlarmFiltering"
            self._absolute_path = lambda: "CISCO-ENTITY-ALARM-MIB:CISCO-ENTITY-ALARM-MIB/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(CISCOENTITYALARMMIB.Cealarmfiltering, ['cealarmnotifiesenable', 'cealarmsyslogenable', 'cealarmfilterprofileindexnext'], name, value)


    class Cealarmdescrmaptable(Entity):
        """
        For each type of entity (represented entPhysicalVendorType
        OID), this table contains a mapping between a unique 
        ceAlarmDescrIndex and entPhysicalvendorType OID.
        
        .. attribute:: cealarmdescrmapentry
        
        	A mapping between an alarm description and a vendor type
        	**type**\: list of  		 :py:class:`Cealarmdescrmapentry <ydk.models.cisco_ios_xe.CISCO_ENTITY_ALARM_MIB.CISCOENTITYALARMMIB.Cealarmdescrmaptable.Cealarmdescrmapentry>`
        
        

        """

        _prefix = 'CISCO-ENTITY-ALARM-MIB'
        _revision = '1999-07-06'

        def __init__(self):
            super(CISCOENTITYALARMMIB.Cealarmdescrmaptable, self).__init__()

            self.yang_name = "ceAlarmDescrMapTable"
            self.yang_parent_name = "CISCO-ENTITY-ALARM-MIB"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ceAlarmDescrMapEntry" : ("cealarmdescrmapentry", CISCOENTITYALARMMIB.Cealarmdescrmaptable.Cealarmdescrmapentry)}

            self.cealarmdescrmapentry = YList(self)
            self._segment_path = lambda: "ceAlarmDescrMapTable"
            self._absolute_path = lambda: "CISCO-ENTITY-ALARM-MIB:CISCO-ENTITY-ALARM-MIB/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(CISCOENTITYALARMMIB.Cealarmdescrmaptable, [], name, value)


        class Cealarmdescrmapentry(Entity):
            """
            A mapping between an alarm description and a vendor type.
            
            .. attribute:: cealarmdescrindex  <key>
            
            	This object uniquely identifies an alarm description
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: cealarmdescrvendortype
            
            	This object specifies an object identifier (typically an enterprise\-specific OID) that uniquely identifies the vendor type of those physical entities that this alarm description applies to
            	**type**\: str
            
            	**pattern:** (([0\-1](\\.[1\-3]?[0\-9]))\|(2\\.(0\|([1\-9]\\d\*))))(\\.(0\|([1\-9]\\d\*)))\*
            
            

            """

            _prefix = 'CISCO-ENTITY-ALARM-MIB'
            _revision = '1999-07-06'

            def __init__(self):
                super(CISCOENTITYALARMMIB.Cealarmdescrmaptable.Cealarmdescrmapentry, self).__init__()

                self.yang_name = "ceAlarmDescrMapEntry"
                self.yang_parent_name = "ceAlarmDescrMapTable"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.cealarmdescrindex = YLeaf(YType.uint32, "ceAlarmDescrIndex")

                self.cealarmdescrvendortype = YLeaf(YType.str, "ceAlarmDescrVendorType")
                self._segment_path = lambda: "ceAlarmDescrMapEntry" + "[ceAlarmDescrIndex='" + self.cealarmdescrindex.get() + "']"
                self._absolute_path = lambda: "CISCO-ENTITY-ALARM-MIB:CISCO-ENTITY-ALARM-MIB/ceAlarmDescrMapTable/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(CISCOENTITYALARMMIB.Cealarmdescrmaptable.Cealarmdescrmapentry, ['cealarmdescrindex', 'cealarmdescrvendortype'], name, value)


    class Cealarmdescrtable(Entity):
        """
        This table contains a description for each alarm type
        defined by each vendor type employed by the system.
        Observe that this table is sparse in nature, as it is
        rarely the case that a physical entity type needs to 
        define every alarm in its alarm space.
        
        .. attribute:: cealarmdescrentry
        
        	A collection of attributes that describe an alarm type
        	**type**\: list of  		 :py:class:`Cealarmdescrentry <ydk.models.cisco_ios_xe.CISCO_ENTITY_ALARM_MIB.CISCOENTITYALARMMIB.Cealarmdescrtable.Cealarmdescrentry>`
        
        

        """

        _prefix = 'CISCO-ENTITY-ALARM-MIB'
        _revision = '1999-07-06'

        def __init__(self):
            super(CISCOENTITYALARMMIB.Cealarmdescrtable, self).__init__()

            self.yang_name = "ceAlarmDescrTable"
            self.yang_parent_name = "CISCO-ENTITY-ALARM-MIB"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ceAlarmDescrEntry" : ("cealarmdescrentry", CISCOENTITYALARMMIB.Cealarmdescrtable.Cealarmdescrentry)}

            self.cealarmdescrentry = YList(self)
            self._segment_path = lambda: "ceAlarmDescrTable"
            self._absolute_path = lambda: "CISCO-ENTITY-ALARM-MIB:CISCO-ENTITY-ALARM-MIB/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(CISCOENTITYALARMMIB.Cealarmdescrtable, [], name, value)


        class Cealarmdescrentry(Entity):
            """
            A collection of attributes that describe an alarm type.
            
            .. attribute:: cealarmdescrindex  <key>
            
            	
            	**type**\: int
            
            	**range:** 0..4294967295
            
            	**refers to**\:  :py:class:`cealarmdescrindex <ydk.models.cisco_ios_xe.CISCO_ENTITY_ALARM_MIB.CISCOENTITYALARMMIB.Cealarmdescrmaptable.Cealarmdescrmapentry>`
            
            .. attribute:: cealarmdescralarmtype  <key>
            
            	This object specifies the alarm type being described
            	**type**\: int
            
            	**range:** 0..255
            
            .. attribute:: cealarmdescrseverity
            
            	This object specifies the severity associated with the alarm type.  An implementation may chose to not allow dynamic severity assignment, in which case it would restrict access to this object to be read\-only.  If an implementation allows dynamic severity assignment, then a management client can revert to the default severity by writing the value '0' to this object.  There exists a class of systems that should implement dynamic severity assignment.  For example, consider a DSLAM (Digital Subscriber Loop Access Multiplexor) designed for both the central office and pedestal environments.  A 'pedestal' is typically a dark\-green metal box mounted on a concrete or stone foundation in which carrier\-class companies house equipment. The central office typically controls the temperature and humidity of the environment, reducing reliance on a system's fans.  Thus, the customer probably has a desire to reduce the  severity of alarms indicating the failure of a fan.  However, a pedestal environment has a much greater reliance on a system's fans.  Thus, the customer probably has a desire to increase the severity of alarms indicating the failure of a fan
            	**type**\: int
            
            	**range:** 0..4
            
            .. attribute:: cealarmdescrtext
            
            	This object specifies a human\-readable message describing the alarm
            	**type**\: str
            
            

            """

            _prefix = 'CISCO-ENTITY-ALARM-MIB'
            _revision = '1999-07-06'

            def __init__(self):
                super(CISCOENTITYALARMMIB.Cealarmdescrtable.Cealarmdescrentry, self).__init__()

                self.yang_name = "ceAlarmDescrEntry"
                self.yang_parent_name = "ceAlarmDescrTable"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.cealarmdescrindex = YLeaf(YType.str, "ceAlarmDescrIndex")

                self.cealarmdescralarmtype = YLeaf(YType.int32, "ceAlarmDescrAlarmType")

                self.cealarmdescrseverity = YLeaf(YType.int32, "ceAlarmDescrSeverity")

                self.cealarmdescrtext = YLeaf(YType.str, "ceAlarmDescrText")
                self._segment_path = lambda: "ceAlarmDescrEntry" + "[ceAlarmDescrIndex='" + self.cealarmdescrindex.get() + "']" + "[ceAlarmDescrAlarmType='" + self.cealarmdescralarmtype.get() + "']"
                self._absolute_path = lambda: "CISCO-ENTITY-ALARM-MIB:CISCO-ENTITY-ALARM-MIB/ceAlarmDescrTable/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(CISCOENTITYALARMMIB.Cealarmdescrtable.Cealarmdescrentry, ['cealarmdescrindex', 'cealarmdescralarmtype', 'cealarmdescrseverity', 'cealarmdescrtext'], name, value)


    class Cealarmtable(Entity):
        """
        This table specifies alarm control and status information
        related to each physical entity contained by the system,
        including the alarms currently being asserted by each physical
        entity capable of generating alarms.
        
        .. attribute:: cealarmentry
        
        	Alarm control and status information related to the  corresponding physical entity, including a list of those alarms currently being asserted by that physical entity
        	**type**\: list of  		 :py:class:`Cealarmentry <ydk.models.cisco_ios_xe.CISCO_ENTITY_ALARM_MIB.CISCOENTITYALARMMIB.Cealarmtable.Cealarmentry>`
        
        

        """

        _prefix = 'CISCO-ENTITY-ALARM-MIB'
        _revision = '1999-07-06'

        def __init__(self):
            super(CISCOENTITYALARMMIB.Cealarmtable, self).__init__()

            self.yang_name = "ceAlarmTable"
            self.yang_parent_name = "CISCO-ENTITY-ALARM-MIB"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ceAlarmEntry" : ("cealarmentry", CISCOENTITYALARMMIB.Cealarmtable.Cealarmentry)}

            self.cealarmentry = YList(self)
            self._segment_path = lambda: "ceAlarmTable"
            self._absolute_path = lambda: "CISCO-ENTITY-ALARM-MIB:CISCO-ENTITY-ALARM-MIB/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(CISCOENTITYALARMMIB.Cealarmtable, [], name, value)


        class Cealarmentry(Entity):
            """
            Alarm control and status information related to the 
            corresponding physical entity, including a list of those
            alarms currently being asserted by that physical entity.
            
            .. attribute:: entphysicalindex  <key>
            
            	
            	**type**\: int
            
            	**range:** 1..2147483647
            
            	**refers to**\:  :py:class:`entphysicalindex <ydk.models.cisco_ios_xe.ENTITY_MIB.ENTITYMIB.Entphysicaltable.Entphysicalentry>`
            
            .. attribute:: cealarmfilterprofile
            
            	This object specifies the alarm filter profile associated with the corresponding physical entity.  An alarm filter profile controls which alarm types the agent will monitor and signal for the corresponding physical entity.  If the value of this object is '0', then the agent monitors and signals all alarms associated with the corresponding physical entity
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: cealarmseverity
            
            	This object specifies the highest severity alarm currently being asserted by the corresponding physical entity.  A value of '0' indicates that there the corresponding physical entity currently is not asserting any alarms
            	**type**\: int
            
            	**range:** 0..4
            
            .. attribute:: cealarmlist
            
            	This object specifies those alarms currently being asserted by the corresponding physical entity.  Note, an alarm indicates a condition, not an event.  An alarm has two states\:      'asserted'  Indicates that the condition described by the                 alarm exists.      'cleared'   Indicates that the condition described by the                 alarm does not exist.  For example, a slot in a chassis may define an alarm that specifies whether the slot contains a module.  At the time of module insertion, the physical entity corresponding to the slot asserts this alarm, and the alarm remains asserted until the  slot becomes empty.  If an alarm is being asserted by the physical entity, then the corresponding bit in the alarm list is set to a one. Observe that if the physical entity is not currently asserting any alarms, then the list will have a length of zero
            	**type**\: str
            
            	**length:** 0..32
            
            

            """

            _prefix = 'CISCO-ENTITY-ALARM-MIB'
            _revision = '1999-07-06'

            def __init__(self):
                super(CISCOENTITYALARMMIB.Cealarmtable.Cealarmentry, self).__init__()

                self.yang_name = "ceAlarmEntry"
                self.yang_parent_name = "ceAlarmTable"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.entphysicalindex = YLeaf(YType.str, "entPhysicalIndex")

                self.cealarmfilterprofile = YLeaf(YType.uint32, "ceAlarmFilterProfile")

                self.cealarmseverity = YLeaf(YType.int32, "ceAlarmSeverity")

                self.cealarmlist = YLeaf(YType.str, "ceAlarmList")
                self._segment_path = lambda: "ceAlarmEntry" + "[entPhysicalIndex='" + self.entphysicalindex.get() + "']"
                self._absolute_path = lambda: "CISCO-ENTITY-ALARM-MIB:CISCO-ENTITY-ALARM-MIB/ceAlarmTable/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(CISCOENTITYALARMMIB.Cealarmtable.Cealarmentry, ['entphysicalindex', 'cealarmfilterprofile', 'cealarmseverity', 'cealarmlist'], name, value)


    class Cealarmhisttable(Entity):
        """
        This table contains a history of ceAlarmIndicate and
        ceAlarmClear traps generated by the agent.
        
        .. attribute:: cealarmhistentry
        
        	The information conveyed by a ceAlarmIndicate or ceAlarmClear trap
        	**type**\: list of  		 :py:class:`Cealarmhistentry <ydk.models.cisco_ios_xe.CISCO_ENTITY_ALARM_MIB.CISCOENTITYALARMMIB.Cealarmhisttable.Cealarmhistentry>`
        
        

        """

        _prefix = 'CISCO-ENTITY-ALARM-MIB'
        _revision = '1999-07-06'

        def __init__(self):
            super(CISCOENTITYALARMMIB.Cealarmhisttable, self).__init__()

            self.yang_name = "ceAlarmHistTable"
            self.yang_parent_name = "CISCO-ENTITY-ALARM-MIB"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ceAlarmHistEntry" : ("cealarmhistentry", CISCOENTITYALARMMIB.Cealarmhisttable.Cealarmhistentry)}

            self.cealarmhistentry = YList(self)
            self._segment_path = lambda: "ceAlarmHistTable"
            self._absolute_path = lambda: "CISCO-ENTITY-ALARM-MIB:CISCO-ENTITY-ALARM-MIB/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(CISCOENTITYALARMMIB.Cealarmhisttable, [], name, value)


        class Cealarmhistentry(Entity):
            """
            The information conveyed by a ceAlarmIndicate or
            ceAlarmClear trap.
            
            .. attribute:: cealarmhistindex  <key>
            
            	An integer value uniquely identifying the entry in the table. The value of this object starts at '1' and monotonically increases for each alarm condition transition monitored by the agent.  If the value of this object is '4294967295', the agent will reset it to '1' upon monitoring the next alarm condition transition
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: cealarmhisttype
            
            	This object specifies whether the agent created the entry as the result of an alarm being asserted or cleared
            	**type**\:  :py:class:`Cealarmhisttype <ydk.models.cisco_ios_xe.CISCO_ENTITY_ALARM_MIB.CISCOENTITYALARMMIB.Cealarmhisttable.Cealarmhistentry.Cealarmhisttype>`
            
            .. attribute:: cealarmhistentphysicalindex
            
            	This object specifies the physical entity that generated the alarm
            	**type**\: int
            
            	**range:** 1..2147483647
            
            .. attribute:: cealarmhistalarmtype
            
            	This object specifies the type of alarm generated
            	**type**\: int
            
            	**range:** 0..255
            
            .. attribute:: cealarmhistseverity
            
            	This object specifies the severity of the alarm generated
            	**type**\:  :py:class:`AlarmSeverity <ydk.models.cisco_ios_xe.CISCO_ENTITY_ALARM_MIB.AlarmSeverity>`
            
            .. attribute:: cealarmhisttimestamp
            
            	This object specifies the value of the sysUpTime object at the time the alarm was generated
            	**type**\: int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'CISCO-ENTITY-ALARM-MIB'
            _revision = '1999-07-06'

            def __init__(self):
                super(CISCOENTITYALARMMIB.Cealarmhisttable.Cealarmhistentry, self).__init__()

                self.yang_name = "ceAlarmHistEntry"
                self.yang_parent_name = "ceAlarmHistTable"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.cealarmhistindex = YLeaf(YType.uint32, "ceAlarmHistIndex")

                self.cealarmhisttype = YLeaf(YType.enumeration, "ceAlarmHistType")

                self.cealarmhistentphysicalindex = YLeaf(YType.int32, "ceAlarmHistEntPhysicalIndex")

                self.cealarmhistalarmtype = YLeaf(YType.int32, "ceAlarmHistAlarmType")

                self.cealarmhistseverity = YLeaf(YType.enumeration, "ceAlarmHistSeverity")

                self.cealarmhisttimestamp = YLeaf(YType.uint32, "ceAlarmHistTimeStamp")
                self._segment_path = lambda: "ceAlarmHistEntry" + "[ceAlarmHistIndex='" + self.cealarmhistindex.get() + "']"
                self._absolute_path = lambda: "CISCO-ENTITY-ALARM-MIB:CISCO-ENTITY-ALARM-MIB/ceAlarmHistTable/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(CISCOENTITYALARMMIB.Cealarmhisttable.Cealarmhistentry, ['cealarmhistindex', 'cealarmhisttype', 'cealarmhistentphysicalindex', 'cealarmhistalarmtype', 'cealarmhistseverity', 'cealarmhisttimestamp'], name, value)

            class Cealarmhisttype(Enum):
                """
                Cealarmhisttype

                This object specifies whether the agent created the entry as

                the result of an alarm being asserted or cleared.

                .. data:: asserted = 1

                .. data:: cleared = 2

                """

                asserted = Enum.YLeaf(1, "asserted")

                cleared = Enum.YLeaf(2, "cleared")



    class Cealarmfilterprofiletable(Entity):
        """
        This table contains a list of alarm filter profiles.
        
        .. attribute:: cealarmfilterprofileentry
        
        	When a physical entity asserts/clears an alarm AND the ceAlarmFilterProfile object is not '0', the agent applies the specified alarm filter profile in processing the alarm. The agent uses the following procedure in processing the transition of an alarm condition of a given type\:  1)  If the alarm list specified by the alarm filter profile's     ceAlarmFilterAlarmsEnabled object specifies that the alarm     type is disabled, then the agent performs no further     processing.  2)  The agent creates an entry in the ceAlarmHistTable.  3)  If the alarm list specified by the alarm filter profile's      ceAlarmFilterNotifiesEnabled object specifies that the alarm     type is enabled, then the agent generates the appropriate     notification.  4)  If the alarm list specified by the alarm filter profile's     ceAlarmFilterSyslogEnabled object specifies that the alarm     type is enabled, then the agent generates the appropriate     syslog message
        	**type**\: list of  		 :py:class:`Cealarmfilterprofileentry <ydk.models.cisco_ios_xe.CISCO_ENTITY_ALARM_MIB.CISCOENTITYALARMMIB.Cealarmfilterprofiletable.Cealarmfilterprofileentry>`
        
        

        """

        _prefix = 'CISCO-ENTITY-ALARM-MIB'
        _revision = '1999-07-06'

        def __init__(self):
            super(CISCOENTITYALARMMIB.Cealarmfilterprofiletable, self).__init__()

            self.yang_name = "ceAlarmFilterProfileTable"
            self.yang_parent_name = "CISCO-ENTITY-ALARM-MIB"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ceAlarmFilterProfileEntry" : ("cealarmfilterprofileentry", CISCOENTITYALARMMIB.Cealarmfilterprofiletable.Cealarmfilterprofileentry)}

            self.cealarmfilterprofileentry = YList(self)
            self._segment_path = lambda: "ceAlarmFilterProfileTable"
            self._absolute_path = lambda: "CISCO-ENTITY-ALARM-MIB:CISCO-ENTITY-ALARM-MIB/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(CISCOENTITYALARMMIB.Cealarmfilterprofiletable, [], name, value)


        class Cealarmfilterprofileentry(Entity):
            """
            When a physical entity asserts/clears an alarm AND the
            ceAlarmFilterProfile object is not '0', the agent applies
            the specified alarm filter profile in processing the alarm.
            The agent uses the following procedure in processing the
            transition of an alarm condition of a given type\:
            
            1)  If the alarm list specified by the alarm filter profile's
                ceAlarmFilterAlarmsEnabled object specifies that the alarm
                type is disabled, then the agent performs no further
                processing.
            
            2)  The agent creates an entry in the ceAlarmHistTable.
            
            3)  If the alarm list specified by the alarm filter profile's 
                ceAlarmFilterNotifiesEnabled object specifies that the alarm
                type is enabled, then the agent generates the appropriate
                notification.
            
            4)  If the alarm list specified by the alarm filter profile's
                ceAlarmFilterSyslogEnabled object specifies that the alarm
                type is enabled, then the agent generates the appropriate
                syslog message.
            
            .. attribute:: cealarmfilterindex  <key>
            
            	This object uniquely identifies the alarm filter profile
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: cealarmfilterstatus
            
            	This object facilitates the creation, modification, or  deletion of a conceptual row in this table.  A management client can create a conceptual row in this table by setting this object to 'createAndWait' or  'createAndGo'.  If a request to create a conceptual row in this table fails, then the system is not capable of supporting any more alarm filters.  Before modifying a conceptual row in this table, the  management client must set this object to 'notInService'. After modifying a conceptual row in this table, the  management client must set this object to 'active'. This operation causes the modifications made to an alarm filter profile to take effect.  An implementation should not allow a conceptual row in this table to be deleted if one or more physical entities reference it
            	**type**\:  :py:class:`RowStatus <ydk.models.cisco_ios_xe.SNMPv2_TC.RowStatus>`
            
            .. attribute:: cealarmfilteralias
            
            	This object specifies an arbitrary name associated with the alarm filter profile by the management client, and provides a non\-volatile 'handle' for the alarm filter profile.  On the first instantiation of an alarm filter profile, the value of this object is a zero\-length string.  However, an agent may choose to set the value to a locally unique default value.  If an implementation supports write access to this object, then the agent is responsible for ensuring the retention of any value written to this object until a management client deletes it.  The level of retention must span reboots and  reinitializations of the network management system, including those that result in different assignments to the value of the entPhysicalIndex associated with the physical entity
            	**type**\: str
            
            .. attribute:: cealarmfilteralarmsenabled
            
            	This object specifies a list of alarms that are enabled
            	**type**\: str
            
            	**length:** 0..32
            
            .. attribute:: cealarmfilternotifiesenabled
            
            	This object specifies a list of alarms for which notification generation is enabled
            	**type**\: str
            
            	**length:** 0..32
            
            .. attribute:: cealarmfiltersyslogenabled
            
            	This object specifies a list of alarms for which syslog message generation is enabled
            	**type**\: str
            
            	**length:** 0..32
            
            

            """

            _prefix = 'CISCO-ENTITY-ALARM-MIB'
            _revision = '1999-07-06'

            def __init__(self):
                super(CISCOENTITYALARMMIB.Cealarmfilterprofiletable.Cealarmfilterprofileentry, self).__init__()

                self.yang_name = "ceAlarmFilterProfileEntry"
                self.yang_parent_name = "ceAlarmFilterProfileTable"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.cealarmfilterindex = YLeaf(YType.uint32, "ceAlarmFilterIndex")

                self.cealarmfilterstatus = YLeaf(YType.enumeration, "ceAlarmFilterStatus")

                self.cealarmfilteralias = YLeaf(YType.str, "ceAlarmFilterAlias")

                self.cealarmfilteralarmsenabled = YLeaf(YType.str, "ceAlarmFilterAlarmsEnabled")

                self.cealarmfilternotifiesenabled = YLeaf(YType.str, "ceAlarmFilterNotifiesEnabled")

                self.cealarmfiltersyslogenabled = YLeaf(YType.str, "ceAlarmFilterSyslogEnabled")
                self._segment_path = lambda: "ceAlarmFilterProfileEntry" + "[ceAlarmFilterIndex='" + self.cealarmfilterindex.get() + "']"
                self._absolute_path = lambda: "CISCO-ENTITY-ALARM-MIB:CISCO-ENTITY-ALARM-MIB/ceAlarmFilterProfileTable/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(CISCOENTITYALARMMIB.Cealarmfilterprofiletable.Cealarmfilterprofileentry, ['cealarmfilterindex', 'cealarmfilterstatus', 'cealarmfilteralias', 'cealarmfilteralarmsenabled', 'cealarmfilternotifiesenabled', 'cealarmfiltersyslogenabled'], name, value)

    def clone_ptr(self):
        self._top_entity = CISCOENTITYALARMMIB()
        return self._top_entity

